# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_main.ipynb.

# %% auto 0
__all__ = ['app', 'version', 'arxiv_top_categories', 'arxiv_sub_categories', 'personalized_papers']

# %% ../nbs/00_main.ipynb 3
import arxiv
import typer
from readnext import __version__
from readnext.arxiv_categories import exists, main, sub
from readnext.arxiv_sync import sync_arxiv
from readnext.embedding import embed_category_papers
from readnext.personalize import get_personalized_papers, save_personalized_papers_in_zotero
from rich import print
from typing_extensions import Annotated

# %% ../nbs/00_main.ipynb 5
app = typer.Typer()

# %% ../nbs/00_main.ipynb 7
@app.command()
def version():
    """Get the current installed version of ReadNext"""
    print(f"Version: {__version__}")

# %% ../nbs/00_main.ipynb 10
@app.command()
def arxiv_top_categories():
    "Display ArXiv main categories. Keys are case sensitive."
    print(main)

# %% ../nbs/00_main.ipynb 13
@app.command()
def arxiv_sub_categories():
    "Display ArXiv sub categories. Keys are case sensitive."
    print(sub)

# %% ../nbs/00_main.ipynb 16
@app.command()
def personalized_papers(category: str, 
                        focus_collection: str, 
                        proposals_collection: Annotated[str, 
                                                        typer.Option("--proposals-collection",
                                                        help="Save personalized papers in Zotero in target Zotero collection.")] = "", 
                        with_artifacts: Annotated[bool, 
                                                  typer.Option("--with-artifacts", 
                                                               "-a",
                                                               help="Add paper artifacts (PDFs & summary files) to Zotero when saving.")] = False,                                                               
                        nb_proposals=10):
    """Get personalized papers of a `focus-collection` from an ArXiv `category`. 
    If the category is `all` then all categories that have been locally synced will be used.
    if --proposals-collection is set, then the papers will be uploaded to the 
    that Zotero collection, otherwise it will only be displayed to the command line.
    """

    # Step 1: Make sure the category exists
    if exists(category):
        # Step 2: get today's list of papers from arXiv
        print("[green]Syncing today's ArXiv latest papers...[/green]")
        sync_arxiv(category)

        # Step 3: create embeddings for each of those new papers
        print("[green]Creating embeddings for each new paper...[/green]")
        embed_category_papers(category)

        # Step 4: get personalized papers
        print("[green]Get personalized papers...[/green]")
        ids = get_personalized_papers(category, focus_collection, nb_proposals)

        # Step 5: save personalized papers in Zotero
        if proposals_collection != "":
            print("[green]Saving personalized papers in Zotero...[/green]")
            save_personalized_papers_in_zotero(ids, proposals_collection, with_artifacts)

        # Step 6: display personalized papers to the command line
        search = arxiv.Search(id_list=ids.keys())

        for index, result in enumerate(search.results()):
            print(str(index + 1) + '. [italic yellow][' + list(ids.values())[index] + '][/italic yellow]  [blue][link=' + str(result) + ']' + result.title + '[/link][/blue]')
    else:
        print("[bold red]Error:[/bold red] [italic red]ArXiv category, or sub-category ID non existing.[/italic red] Please specify a valid category ID.")



# %% ../nbs/00_main.ipynb 18
#| eval: false
if __name__ == "__main__":
    app()
